@@ -135,10 +135,23 @@ def _build_godot_uri(project):
 
     _version = ':{0}:{1}:{2}:{3}:{4}'.format(project.config.godot.version, project.config.godot.release, _system, project.config.godot.arch, _mono )
 
+    # verify that the version is in our table
     if (_version in godot_versions):
         _uri = godot_versions[_version]
+        return _uri 
 
-    return _uri
+    # mac no longer specifies architecture (universal)
+    _arch = project.config.godot.arch 
+    if _system == "darwin":
+        _arch = ""
+        _version = ':{0}:{1}:{2}:{3}:{4}'.format(project.config.godot.version, project.config.godot.release, _system, _arch, _mono )
+
+    # verify that the version is in our table (again)
+    if (_version in godot_versions):
+        _uri = godot_versions[_version]
+        return _uri 
+
+    raise Exception("Version [{0}] Not Available".format(_version))
 
 
 def _build_godot_uriX(project):
